from distutils.core import setup

setup(
  name = 'pysinch',
  version = '1.0.0',
  description = 'Python wrapper for Sinch Voice REST APIs',
  long_description = 'Python wrapper for Sinch Voice REST APIs',
  author = 'Ismail Pelaseyed',
  author_email = 'ismail@bitcall.io',
  url = 'https://github.com/Bitcall/pysinch.git',
  keywords = ['voice', 'sinch'],
  py_modules = ['pysinch'],
  classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Communications"
  ],
)
